Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Characteristics ¶
type CounterGen ¶
type CounterGen struct {
// contains filtered or unexported fields
}
TODO(bwplotka): Improve. Does not work well (: Too naive. Add resets etc.
func NewCounterGen ¶
func NewCounterGen(random *rand.Rand, mint, maxt int64, opts Characteristics) *CounterGen
func (*CounterGen) At ¶
func (g *CounterGen) At() (int64, float64)
func (*CounterGen) Err ¶
func (g *CounterGen) Err() error
func (*CounterGen) Next ¶
func (g *CounterGen) Next() bool
type GaugeGen ¶
type GaugeGen struct {
// contains filtered or unexported fields
}
func NewGaugeGen ¶
func NewGaugeGen(random *rand.Rand, mint, maxt int64, opts Characteristics) *GaugeGen
type Series ¶
type Series interface {
// Labels returns the complete set of labels identifying the series.
Labels() labels.Labels
// Iterator returns a new iterator of the data of the series.
// TODO(bwplotka): Consider moving this to tsdb.SeriesIterator if required. This means adding `Seek` method.
Iterator() SeriesIterator
}
Series exposes a single time series.
type SeriesGen ¶
type SeriesGen struct {
SeriesIterator
// contains filtered or unexported fields
}
func NewSeriesGen ¶
func NewSeriesGen(lset labels.Labels, si SeriesIterator) *SeriesGen
func (*SeriesGen) Iterator ¶
func (s *SeriesGen) Iterator() SeriesIterator
type SeriesIterator ¶
type SeriesIterator interface {
// At returns the current timestamp/value pair.
At() (t int64, v float64)
// Next advances the iterator by one.
Next() bool
// Err returns current error.
Err() error
}
SeriesIterator iterates over the data of a time series. Simplified version of github.com/prometheus/prometheus/tsdb.SeriesIterator
Click to show internal directories.
Click to hide internal directories.